!!! note
    This Class is not meant to be instantiated directly, but rather accessed through the `transactional` Property on an
    instance of [AsyncClient](async_client.md). For more details, see the [Guide](../../guides/transactional.md).

::: anaplan_sdk._async_clients._AsyncTransactionalClient
